@@ -17,8 +17,8 @@
  * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * Author: David Zeuthen <davidz@redhat.com>
- *         Debarshi Ray <debarshir@gnome.org>
+ * Authors: David Zeuthen <davidz@redhat.com>
+ *          Debarshi Ray <debarshir@gnome.org>
  */
 
 #include "config.h"
@@ -28,6 +28,7 @@
 #include <json-glib/json-glib.h>
 
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
 #include "goagoogleprovider.h"
 #include "goahttpclient.h"
@@ -61,6 +62,7 @@ struct _GoaGoogleProviderClass
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaGoogleProvider, goa_google_provider, GOA_TYPE_OAUTH2_PROVIDER,
+                         goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
 							 "google",
@@ -409,7 +411,7 @@ build_object (GoaProvider         *provider,
                         "imap-supported",  TRUE,
                         "imap-host",       "imap.gmail.com",
                         "imap-user-name",  email_address,
-                        "imap-use-tls",    TRUE,
+                        "imap-use-ssl",    TRUE,
                         "smtp-supported",  TRUE,
                         "smtp-host",       "smtp.gmail.com",
                         "smtp-user-name",  email_address,
@@ -526,18 +528,12 @@ build_object (GoaProvider         *provider,
   ret = TRUE;
 
  out:
-  if (documents != NULL)
-    g_object_unref (documents);
-  if (chat != NULL)
-    g_object_unref (chat);
-  if (contacts != NULL)
-    g_object_unref (contacts);
-  if (calendar != NULL)
-    g_object_unref (calendar);
-  if (mail != NULL)
-    g_object_unref (mail);
-  if (account != NULL)
-    g_object_unref (account);
+  g_clear_object (&documents);
+  g_clear_object (&chat);
+  g_clear_object (&contacts);
+  g_clear_object (&calendar);
+  g_clear_object (&mail);
+  g_clear_object (&account);
   return ret;
 }
 
@@ -581,10 +577,6 @@ ensure_credentials_sync (GoaProvider   *provider,
     {
       if (error != NULL)
         {
-          g_prefix_error (error,
-                          _("Credentials not found in keyring (%s, %d): "),
-                          g_quark_to_string ((*error)->domain),
-                          (*error)->code);
           (*error)->domain = GOA_ERROR;
           (*error)->code = GOA_ERROR_NOT_AUTHORIZED;
         }
@@ -601,7 +593,7 @@ ensure_credentials_sync (GoaProvider   *provider,
         {
           *error = g_error_new (GOA_ERROR,
                                 GOA_ERROR_NOT_AUTHORIZED,
-                                _("Did not find password with username `%s' in credentials"),
+                                _("Did not find password with identity `%s' in credentials"),
                                 username);
         }
       goto out;
@@ -759,6 +751,7 @@ on_handle_get_password (GoaPasswordBased      *interface,
   GoaProvider *provider;
   GError *error;
   GVariant *credentials;
+  const gchar *identity;
   gchar *password;
 
   /* TODO: maybe log what app is requesting access */
@@ -768,6 +761,7 @@ on_handle_get_password (GoaPasswordBased      *interface,
 
   object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (interface)));
   account = goa_object_peek_account (object);
+  identity = goa_account_get_identity (account);
   provider = goa_provider_get_for_provider_type (goa_account_get_provider_type (account));
 
   error = NULL;
@@ -786,7 +780,8 @@ on_handle_get_password (GoaPasswordBased      *interface,
       g_dbus_method_invocation_return_error (invocation,
                                              GOA_ERROR,
                                              GOA_ERROR_FAILED, /* TODO: more specific */
-                                             _("Did not find password in credentials"));
+                                             _("Did not find password with identity `%s' in credentials"),
+                                             identity);
       goto out;
     }
 
