@@ -811,16 +811,13 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
       uri = soup_message_get_uri (message);
 
       /* Two cases:
-       * the data we look for might be in the query part or in the fragment
-       * part of the URI.
-       *
-       * Currently only facebook client-side flow uses the fragment to pass
-       * the access_token and expiration, though, so we are actually looking
-       * for the auth code in the query and the access_token in the fragment.
-       * This might need changes (FIXME) to be more generalized */
+       * 1) we can have either the auth code in the query part of the
+       *    URI, with which we'll obtain the token, or
+       * 2) the access_token and other information directly in the
+       *    fragment part of the URI.
+       */
       if (soup_uri_get_query (uri) != NULL)
         {
-          /* case 1, the data we are expecting is in the query part of the URI */
           GHashTable *key_value_pairs;
 
           key_value_pairs = soup_form_decode (uri->query);
@@ -844,16 +841,15 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
         }
       else if (soup_uri_get_fragment (uri) != NULL)
         {
-          /* case 2, the data we are expecting is in the fragment part of the
-           * URI */
           GHashTable *key_value_pairs;
 
           /* fragment is encoded into a key/value pairs for the token and
            * expiration values, using the same syntax as a URL query */
           key_value_pairs = soup_form_decode (soup_uri_get_fragment (uri));
 
-          /* we might use oauth2_proxy_extract_access_token() here but we need
-           * also to extract the expire time */
+          /* We might use oauth2_proxy_extract_access_token() here but
+           * we can also extract other information.
+           */
           data->access_token = g_strdup (g_hash_table_lookup (key_value_pairs, "access_token"));
           if (data->access_token != NULL)
             {
@@ -867,6 +863,8 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
               if (expires_in_str != NULL)
                  data->access_token_expires_in = atoi (expires_in_str);
 
+              data->refresh_token = g_strdup (g_hash_table_lookup (key_value_pairs, "refresh_token"));
+
               gtk_dialog_response (data->dialog, GTK_RESPONSE_OK);
             }
           else
@@ -1036,9 +1034,10 @@ get_tokens_and_identity (GoaOAuth2Provider  *provider,
   gtk_widget_show_all (GTK_WIDGET (vbox));
   gtk_dialog_run (GTK_DIALOG (dialog));
 
-  /* we can have either the auth code, with which we'll obtain the token, or
+  /* We can have either the auth code, with which we'll obtain the token, or
    * the token directly if we are using a client side flow, since we don't
-   * need to pass the code to the remote application */
+   * need to pass the code to the remote application.
+   */
   if (data.authorization_code == NULL && data.access_token == NULL)
     {
       if (data.error == NULL)
@@ -1520,8 +1519,6 @@ goa_oauth2_provider_get_access_token_sync (GoaOAuth2Provider  *provider,
     {
       if (error != NULL)
         {
-          g_prefix_error (error, _("Credentials not found in keyring (%s, %d): "),
-                          g_quark_to_string ((*error)->domain), (*error)->code);
           (*error)->domain = GOA_ERROR;
           (*error)->code = GOA_ERROR_NOT_AUTHORIZED;
         }
@@ -1625,8 +1622,6 @@ goa_oauth2_provider_get_access_token_sync (GoaOAuth2Provider  *provider,
     {
       if (error != NULL)
         {
-          g_prefix_error (error, _("Error storing credentials in keyring (%s, %d): "),
-                          g_quark_to_string ((*error)->domain), (*error)->code);
           (*error)->domain = GOA_ERROR;
           (*error)->code = GOA_ERROR_NOT_AUTHORIZED;
         }
