@@ -27,6 +27,7 @@
 
 #include "goahttpclient.h"
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goaowncloudprovider.h"
 #include "goaeditablelabel.h"
 #include "goautils.h"
@@ -59,6 +60,7 @@ struct _GoaOwncloudProviderClass
  */
 
 G_DEFINE_TYPE_WITH_CODE (GoaOwncloudProvider, goa_owncloud_provider, GOA_TYPE_PROVIDER,
+                         goa_provider_ensure_extension_points_registered ();
                          g_io_extension_point_implement (GOA_PROVIDER_EXTENSION_POINT_NAME,
 							 g_define_type_id,
 							 "owncloud",
@@ -340,8 +342,6 @@ ensure_credentials_sync (GoaProvider         *provider,
     {
       if (error != NULL)
         {
-          g_prefix_error (error, _("Credentials not found in keyring (%s, %d): "),
-                          g_quark_to_string ((*error)->domain), (*error)->code);
           (*error)->domain = GOA_ERROR;
           (*error)->code = GOA_ERROR_NOT_AUTHORIZED;
         }
@@ -361,7 +361,7 @@ ensure_credentials_sync (GoaProvider         *provider,
         {
           *error = g_error_new (GOA_ERROR,
                                 GOA_ERROR_NOT_AUTHORIZED,
-                                _("Did not find password with username `%s' in credentials"),
+                                _("Did not find password with identity `%s' in credentials"),
                                 username);
         }
       goto out;
@@ -643,8 +643,25 @@ create_account_details_ui (GoaProvider    *provider,
   gtk_widget_show (label);
   gtk_container_add (GTK_CONTAINER (data->progress_grid), label);
 
-  gtk_window_get_size (GTK_WINDOW (data->dialog), &width, NULL);
-  gtk_widget_set_size_request (GTK_WIDGET (data->dialog), width, -1);
+  if (new_account)
+    {
+      gtk_window_get_size (GTK_WINDOW (data->dialog), &width, NULL);
+      gtk_widget_set_size_request (GTK_WIDGET (data->dialog), width, -1);
+    }
+  else
+    {
+      GtkWindow *parent;
+
+      /* Keep in sync with GoaPanelAddAccountDialog in
+       * gnome-control-center.
+       */
+      parent = gtk_window_get_transient_for (GTK_WINDOW (data->dialog));
+      if (parent != NULL)
+        {
+          gtk_window_get_size (parent, &width, NULL);
+          gtk_widget_set_size_request (GTK_WIDGET (data->dialog), (gint) (0.5 * width), -1);
+        }
+    }
 }
 
 /* ---------------------------------------------------------------------------------------------------- */
@@ -1089,6 +1106,7 @@ on_handle_get_password (GoaPasswordBased      *interface,
   GoaProvider *provider;
   GError *error;
   GVariant *credentials;
+  const gchar *identity;
   gchar *password;
 
   /* TODO: maybe log what app is requesting access */
@@ -1098,6 +1116,7 @@ on_handle_get_password (GoaPasswordBased      *interface,
 
   object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (interface)));
   account = goa_object_peek_account (object);
+  identity = goa_account_get_identity (account);
   provider = goa_provider_get_for_provider_type (goa_account_get_provider_type (account));
 
   error = NULL;
@@ -1116,7 +1135,8 @@ on_handle_get_password (GoaPasswordBased      *interface,
       g_dbus_method_invocation_return_error (invocation,
                                              GOA_ERROR,
                                              GOA_ERROR_FAILED, /* TODO: more specific */
-                                             _("Did not find password in credentials"));
+                                             _("Did not find password with identity `%s' in credentials"),
+                                             identity);
       goto out;
     }
 
