@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -27,9 +27,11 @@
 
 #include "goalogging.h"
 #include "goaprovider.h"
+#include "goaprovider-priv.h"
 #include "goaexchangeprovider.h"
 #include "goagoogleprovider.h"
 #include "goafacebookprovider.h"
+#include "goaimapsmtpprovider.h"
 #include "goaowncloudprovider.h"
 #include "goayahooprovider.h"
 #include "goatwitterprovider.h"
@@ -628,19 +630,33 @@ goa_provider_get_credentials_generation_real (GoaProvider *provider)
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static void
-ensure_ep_and_builtins (void)
+void
+goa_provider_ensure_extension_points_registered (void)
 {
   static gsize once_init_value = 0;
 
   if (g_once_init_enter (&once_init_value))
     {
       GIOExtensionPoint *extension_point;
-      static volatile GType type = 0;
 
       extension_point = g_io_extension_point_register (GOA_PROVIDER_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (extension_point, GOA_TYPE_PROVIDER);
 
+      g_once_init_leave (&once_init_value, 1);
+    }
+}
+
+static void
+ensure_builtins_loaded (void)
+{
+  static gsize once_init_value = 0;
+
+  goa_provider_ensure_extension_points_registered ();
+
+  if (g_once_init_enter (&once_init_value))
+    {
+      static volatile GType type = 0;
+
       /* The order is in which the providers' types are created is
        * important because it affects the order in which they are
        * returned by goa_provider_get_all.
@@ -663,6 +679,9 @@ ensure_ep_and_builtins (void)
 #ifdef GOA_EXCHANGE_ENABLED
       type = GOA_TYPE_EXCHANGE_PROVIDER;
 #endif
+#ifdef GOA_IMAP_SMTP_ENABLED
+      type = GOA_TYPE_IMAP_SMTP_PROVIDER;
+#endif
 #ifdef GOA_KERBEROS_ENABLED
       type = GOA_TYPE_KERBEROS_PROVIDER;
 #endif
@@ -679,7 +698,6 @@ ensure_ep_and_builtins (void)
     }
 }
 
-
 /* ---------------------------------------------------------------------------------------------------- */
 
 /**
@@ -700,7 +718,7 @@ goa_provider_get_for_provider_type (const gchar *provider_type)
   GIOExtensionPoint *extension_point;
   GoaProvider *ret;
 
-  ensure_ep_and_builtins ();
+  ensure_builtins_loaded ();
 
   ret = NULL;
 
@@ -732,7 +750,7 @@ goa_provider_get_all (void)
   GList *l;
   GIOExtensionPoint *extension_point;
 
-  ensure_ep_and_builtins ();
+  ensure_builtins_loaded ();
 
   ret = NULL;
   extension_point = g_io_extension_point_lookup (GOA_PROVIDER_EXTENSION_POINT_NAME);
